@@ -118,16 +118,22 @@ Request::Request(Client *client, Method m, std::string url__) : url_(std::move(u
     curl_easy_setopt(this->easy, CURLOPT_WRITEDATA, this);
     curl_easy_setopt(this->easy, CURLOPT_HEADERFUNCTION, header_cb);
     curl_easy_setopt(this->easy, CURLOPT_HEADERDATA, this);
-    // curl_easy_setopt(this->easy, CURLOPT_VERBOSE, 1L);
+    if (this->global->verbose()) {
+        curl_easy_setopt(this->easy, CURLOPT_VERBOSE, 1L);
+    }
     curl_easy_setopt(this->easy, CURLOPT_ERRORBUFFER, this->error);
     curl_easy_setopt(this->easy, CURLOPT_PRIVATE, this);
     curl_easy_setopt(this->easy, CURLOPT_NOPROGRESS, 1L);
     curl_easy_setopt(this->easy, CURLOPT_XFERINFOFUNCTION, prog_cb);
     curl_easy_setopt(this->easy, CURLOPT_XFERINFODATA, this);
+#if CURL_AT_LEAST_VERSION(7, 85, 0)
+    curl_easy_setopt(this->easy, CURLOPT_PROTOCOLS_STR, "HTTPS,HTTP");
+#else
     curl_easy_setopt(this->easy, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS);
+#endif
 
     // enable altsvc support, which allows us to switch to http3
-    curl_easy_setopt(this->easy, CURLOPT_ALTSVC_CTRL, CURLALTSVC_H1|CURLALTSVC_H2|CURLALTSVC_H3);
+    curl_easy_setopt(this->easy, CURLOPT_ALTSVC_CTRL, CURLALTSVC_H1 | CURLALTSVC_H2 | CURLALTSVC_H3);
     curl_easy_setopt(this->easy, CURLOPT_ALTSVC, client->alt_svc_cache_path().c_str());
 
     // default to all supported encodings
